Pillow
======

Pillow is the 'friendly' PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

.. image:: https://travis-ci.org/python-pillow/Pillow.svg?branch=master
   :target: https://travis-ci.org/python-pillow/Pillow
   :alt: Travis CI build status

.. image:: https://pypip.in/v/Pillow/badge.png
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/Pillow/badge.png
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Number of PyPI downloads

.. image:: https://coveralls.io/repos/python-pillow/Pillow/badge.png?branch=master
    :target: https://coveralls.io/r/python-pillow/Pillow?branch=master
    :alt: Test coverage

To start using Pillow, please read the :doc:`installation
instructions <installation>`.

You can get the source and contribute at
https://github.com/python-pillow/Pillow. You can download archives
and old versions from `PyPI <https://pypi.python.org/pypi/Pillow>`_.

.. toctree::
   :maxdepth: 2

   installation
   about
   guides
   reference/index.rst
   handbook/appendices
   original-readme

Support Pillow!
===============

PIL needs you! Please help us maintain the Python Imaging Library here:

- `GitHub <https://github.com/python-pillow/Pillow>`_
- `Freenode <irc://irc.freenode.net#pil>`_
- `Image-SIG <http://mail.python.org/mailman/listinfo/image-sig>`_

Financial
---------

Pillow is a volunteer effort led by Alex Clark. If you can't help with
development please consider helping us financially. Your assistance would
be very much appreciated!

.. note:: Contributors please add your name and donation preference here.

======================================= =======================================
**Developer**                           **Preference**
======================================= =======================================
Alex Clark (fork author)                http://gittip.com/aclark4life
======================================= =======================================

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
